tinymce.addI18n('hr',{
"Cut": "Izre\u017ei",
"Heading 5": "Naslov 5",
"Header 2": "Zaglavlje 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Va\u0161 preglednik ne podr\u017eava direktan pristup me\u0111uspremniku. Molimo Vas da umjesto toga koristite tipkovni\u010dke kratice Ctrl+X\/C\/V.",
"Heading 4": "Naslov 4",
"Div": "DIV",
"Heading 2": "Naslov 2",
"Paste": "Zalijepi",
"Close": "Zatvori",
"Font Family": "Obitelj fonta",
"Pre": "PRE",
"Align right": "Poravnaj desno",
"New document": "Novi dokument",
"Blockquote": "BLOCKQUOTE",
"Numbered list": "Numerirana lista",
"Heading 1": "Naslov 1",
"Headings": "Naslovi",
"Increase indent": "Pove\u0107aj uvla\u010denje",
"Formats": "Formati",
"Headers": "Zaglavlja",
"Select all": "Ozna\u010di sve",
"Header 3": "Zaglavlje 3",
"Blocks": "Blokovi",
"Undo": "Poni\u0161ti",
"Strikethrough": "Crta kroz sredinu",
"Bullet list": "Lista",
"Header 1": "Zaglavlje 1",
"Superscript": "Eksponent",
"Clear formatting": "Ukloni oblikovanje",
"Font Sizes": "Veli\u010dine fonta",
"Subscript": "Indeks",
"Header 6": "Zaglavlje 6",
"Redo": "Vrati",
"Paragraph": "Paragraf",
"Ok": "U redu",
"Bold": "Podebljano",
"Code": "CODE oznaka",
"Italic": "Kurziv",
"Align center": "Poravnaj po sredini",
"Header 5": "Zaglavlje 5",
"Heading 6": "Naslov 6",
"Heading 3": "Naslov 3",
"Decrease indent": "Smanji uvla\u010denje",
"Header 4": "Zaglavlje 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Akcija zalijepi od sada lijepi \u010disti tekst. Sadr\u017eaj \u0107e biti zaljepljen kao \u010disti tekst sve dok ne isklju\u010dite ovu opciju.",
"Underline": "Crta ispod",
"Cancel": "Odustani",
"Justify": "Obostrano poravnanje",
"Inline": "Unutarnje",
"Copy": "Kopiraj",
"Align left": "Poravnaj lijevo",
"Visual aids": "Vizualna pomo\u0107",
"Lower Greek": "Mala gr\u010dka slova",
"Square": "Kvadrat",
"Default": "Zadano",
"Lower Alpha": "Mala slova",
"Circle": "Krug",
"Disc": "To\u010dka",
"Upper Alpha": "Velika slova",
"Upper Roman": "Velika rimska slova",
"Lower Roman": "Mala rimska slova",
"Name": "Ime",
"Anchor": "Sidro",
"You have unsaved changes are you sure you want to navigate away?": "Postoje ne pohranjene izmjene, jeste li sigurni da \u017eelite oti\u0107i?",
"Restore last draft": "Vrati posljednju skicu",
"Special character": "Poseban znak",
"Source code": "Izvorni kod",
"B": "B",
"R": "R",
"G": "G",
"Color": "Boja",
"Right to left": "S desna na lijevo",
"Left to right": "S lijeva na desno",
"Emoticons": "Emotikoni",
"Robots": "Roboti pretra\u017eiva\u010da",
"Document properties": "Svojstva dokumenta",
"Title": "Naslov",
"Keywords": "Klju\u010dne rije\u010di",
"Encoding": "Kodna stranica",
"Description": "Opis",
"Author": "Autor",
"Fullscreen": "Cijeli ekran",
"Horizontal line": "Horizontalna linija",
"Horizontal space": "Horizontalan razmak",
"Insert\/edit image": "Umetni\/izmijeni sliku",
"General": "Op\u0107enito",
"Advanced": "Napredno",
"Source": "Izvor",
"Border": "Rub",
"Constrain proportions": "Zadr\u017ei proporcije",
"Vertical space": "Okomit razmak",
"Image description": "Opis slike",
"Style": "Stil",
"Dimensions": "Dimenzije",
"Insert image": "Umetni sliku",
"Zoom in": "Pove\u0107aj",
"Contrast": "Kontrast",
"Back": "Natrag",
"Gamma": "Gamma",
"Flip horizontally": "Obrni horizontalno",
"Resize": "Promjeni veli\u010dinu",
"Sharpen": "Izo\u0161travanje",
"Zoom out": "Smanji",
"Image options": "Opcije slike",
"Apply": "Primijeni",
"Brightness": "Svjetlina",
"Rotate clockwise": "Rotiraj desno",
"Rotate counterclockwise": "Rotiraj lijevo",
"Edit image": "Uredi sliku",
"Color levels": "Razine boje",
"Crop": "Obre\u017ei",
"Orientation": "Orijentacija",
"Flip vertically": "Obrni vertikalno",
"Invert": "Invertiraj",
"Insert date\/time": "Umetni datum\/vrijeme",
"Remove link": "Ukloni poveznicu",
"Url": "Url",
"Text to display": "Tekst za prikaz",
"Anchors": "Kra\u0107e poveznice",
"Insert link": "Umetni poveznicu",
"New window": "Novi prozor",
"None": "Ni\u0161ta",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Izgleda da je URL koji ste upisali vanjski link. \u017delite li dodati obavezan http:\/\/ prefiks?",
"Target": "Meta",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Izgleda da je URL koji ste upisali e-mail adresa. \u017delite li dodati obavezan mailto: prefiks?",
"Insert\/edit link": "Umetni\/izmijeni poveznicu",
"Insert\/edit video": "Umetni\/izmijeni video",
"Poster": "Poster",
"Alternative source": "Alternativni izvor",
"Paste your embed code below:": "Umetnite va\u0161 kod za ugradnju ispod:",
"Insert video": "Umetni video",
"Embed": "Ugradi",
"Nonbreaking space": "Neprekidaju\u0107i razmak",
"Page break": "Prijelom stranice",
"Paste as text": "Zalijepi kao tekst",
"Preview": "Pregled",
"Print": "Ispis",
"Save": "Spremi",
"Could not find the specified string.": "Tra\u017eeni tekst nije prona\u0111en",
"Replace": "Zamijeni",
"Next": "Slijede\u0107i",
"Whole words": "Cijele rije\u010di",
"Find and replace": "Prona\u0111i i zamijeni",
"Replace with": "Zamijeni s",
"Find": "Tra\u017ei",
"Replace all": "Zamijeni sve",
"Match case": "Pazi na mala i velika slova",
"Prev": "Prethodni",
"Spellcheck": "Provjeri pravopis",
"Finish": "Zavr\u0161i",
"Ignore all": "Zanemari sve",
"Ignore": "Zanemari",
"Add to Dictionary": "Dodaj u rje\u010dnik",
"Insert row before": "Umetni redak prije",
"Rows": "Redci",
"Height": "Visina",
"Paste row after": "Zalijepi redak nakon",
"Alignment": "Poravnanje",
"Border color": "Boja ruba",
"Column group": "Grupirani stupci",
"Row": "Redak",
"Insert column before": "Umetni stupac prije",
"Split cell": "Razdvoji polja",
"Cell padding": "Razmak unutar polja",
"Cell spacing": "Razmak izme\u0111u polja",
"Row type": "Vrsta redka",
"Insert table": "Umetni tablicu",
"Body": "Sadr\u017eaj",
"Caption": "Natpis",
"Footer": "Podno\u017eje",
"Delete row": "Izbri\u0161i redak",
"Paste row before": "Zalijepi redak prije",
"Scope": "Doseg",
"Delete table": "Izbri\u0161i tablicu",
"H Align": "H Poravnavanje",
"Top": "Vrh",
"Header cell": "Polje zaglavlja",
"Column": "Stupac",
"Row group": "Grupirani redci",
"Cell": "Polje",
"Middle": "Sredina",
"Cell type": "Vrsta polja",
"Copy row": "Kopiraj redak",
"Row properties": "Svojstva redka",
"Table properties": "Svojstva tablice",
"Bottom": "Dno",
"V Align": "V Poravnavanje",
"Header": "Zaglavlje",
"Right": "Desno",
"Insert column after": "Umetni stupac nakon",
"Cols": "Stupci",
"Insert row after": "Umetni redak nakon",
"Width": "\u0160irina",
"Cell properties": "Svojstva polja",
"Left": "Lijevo",
"Cut row": "Izre\u017ei redak",
"Delete column": "Izbri\u0161i stupac",
"Center": "Sredina",
"Merge cells": "Spoji polja",
"Insert template": "Umetni predlo\u017eak",
"Templates": "Predlo\u0161ci",
"Background color": "Boja pozadine",
"Custom...": "Prilago\u0111eno...",
"Custom color": "Prilago\u0111ena boja",
"No color": "Bez boje",
"Text color": "Boja teksta",
"Show blocks": "Prika\u017ei blokove",
"Show invisible characters": "Prika\u017ei nevidljive znakove",
"Words: {0}": "Rije\u010di: {0}",
"Insert": "Umetni",
"File": "Datoteka",
"Edit": "Izmijeni",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Pritisni ALT-F9 za izbornik. Pritisni ALT-F10 za alatnu traku. Pritisni ALT-0 za pomo\u0107",
"Tools": "Alati",
"View": "Pogled",
"Table": "Tablica",
"Format": "Oblikuj"
});