tinymce.addI18n('vi_VN',{
"Cut": "C\u1eaft",
"Heading 5": "Ti\u00eau \u0111\u1ec1 5",
"Header 2": "Ti\u00eau \u0111\u1ec1 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Tr\u00ecnh duy\u1ec7t c\u1ee7a b\u1ea1n kh\u00f4ng h\u1ed7 tr\u1ee3 truy c\u1eadp clipboard, vui l\u00f2ng s\u1eed d\u1ee5ng c\u00e1c t\u1ed5 h\u1ee3p Ctrl + X, C, V.",
"Heading 4": "Ti\u00eau \u0111\u1ec1 4",
"Div": "Khung",
"Heading 2": "Ti\u00eau \u0111\u1ec1 2",
"Paste": "D\u00e1n",
"Close": "\u0110\u00f3ng",
"Font Family": "Ph\u00f4ng",
"Pre": "\u0110\u1ecbnh d\u1ea1ng",
"Align right": "Canh ph\u1ea3i",
"New document": "T\u1ea1o t\u00e0i li\u1ec7u m\u1edbi",
"Blockquote": "Tr\u00edch",
"Numbered list": "Danh s\u00e1ch s\u1ed1",
"Heading 1": "Ti\u00eau \u0111\u1ec1 1",
"Headings": "Ti\u00eau \u0111\u1ec1",
"Increase indent": "L\u00f9i v\u00e0o",
"Formats": "\u0110\u1ecbnh d\u1ea1ng",
"Headers": "\u0110\u1ea7u trang",
"Select all": "Ch\u1ecdn t\u1ea5t c\u1ea3",
"Header 3": "Ti\u00eau \u0111\u1ec1 3",
"Blocks": "Bao",
"Undo": "Hu\u1ef7 thao t\u00e1c",
"Strikethrough": "G\u1ea1ch ngang",
"Bullet list": "D\u1ea5u \u0111\u1ea7u d\u00f2ng",
"Header 1": "Ti\u00eau \u0111\u1ec1 1",
"Superscript": "Tr\u00ean d\u00f2ng",
"Clear formatting": "Xo\u00e1 \u0111\u1ecbnh d\u1ea1ng",
"Font Sizes": "K\u00edch th\u01b0\u1edbc ph\u00f4ng",
"Subscript": "D\u01b0\u1edbi d\u00f2ng",
"Header 6": "Ti\u00eau \u0111\u1ec1 6",
"Redo": "Ho\u00e0n t\u00e1t",
"Paragraph": "\u0110o\u1ea1n v\u0103n",
"Ok": "OK",
"Bold": "T\u00f4 \u0111\u1eadm",
"Code": "M\u00e3",
"Italic": "In nghi\u00eang",
"Align center": "Canh gi\u1eefa",
"Header 5": "Ti\u00eau \u0111\u1ec1 5",
"Heading 6": "Ti\u00eau \u0111\u1ec1 6",
"Heading 3": "Ti\u00eau \u0111\u1ec1 3",
"Decrease indent": "L\u00f9i ra",
"Header 4": "Ti\u00eau \u0111\u1ec1 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "D\u00e1n b\u00e2y gi\u1edd l\u00e0 \u1edf ch\u1ebf \u0111\u1ed9 v\u0103n b\u1ea3n \u0111\u01a1n gi\u1ea3n. N\u1ed9i dung s\u1ebd \u0111\u01b0\u1ee3c d\u00e1n nh\u01b0 \u0111\u1ed3ng b\u1eb1ng v\u0103n b\u1ea3n cho \u0111\u1ebfn khi b\u1ea1n chuy\u1ec3n \u0111\u1ed5i t\u00f9y ch\u1ecdn n\u00e0y.",
"Underline": "G\u1ea1ch d\u01b0\u1edbi",
"Cancel": "Hu\u1ef7",
"Justify": "Canh \u0111\u1ec1u hai b\u00ean",
"Inline": "C\u00f9ng d\u00f2ng",
"Copy": "Ch\u00e9p",
"Align left": "Canh tr\u00e1i",
"Visual aids": "Hi\u1ec7n khung so\u1ea1n th\u1ea3o",
"Lower Greek": "S\u1ed1 hy l\u1ea1p th\u01b0\u1eddng",
"Square": "\u00d4 vu\u00f4ng",
"Default": "Ng\u1ea7m \u0111\u1ecbnh",
"Lower Alpha": "K\u00fd t\u1ef1 th\u01b0\u1eddng",
"Circle": "H\u00ecnh tr\u00f2n",
"Disc": "H\u00ecnh tr\u00f2n m\u1ecfng",
"Upper Alpha": "K\u00fd t\u1ef1 hoa",
"Upper Roman": "S\u1ed1 la m\u00e3 hoa",
"Lower Roman": "S\u1ed1 la m\u00e3 th\u01b0\u1eddng",
"Name": "T\u00ean",
"Anchor": "Neo",
"You have unsaved changes are you sure you want to navigate away?": "B\u1ea1n ch\u01b0a l\u01b0u c\u00e1c thay \u0111\u1ed5i, b\u1ea1n c\u00f3 th\u1eadt s\u1ef1 mu\u1ed1n \u0111\u00f3ng ?",
"Restore last draft": "Ph\u1ee5c h\u1ed3i b\u1ea3n l\u01b0u g\u1ea7n nh\u1ea5t",
"Special character": "K\u00fd t\u1ef1 \u0111\u1eb7c bi\u1ec7t",
"Source code": "M\u00e3 ngu\u1ed3n",
"B": "B",
"R": "R",
"G": "G",
"Color": "M\u00e0u",
"Right to left": "Ph\u1ea3i sang tr\u00e1i",
"Left to right": "Tr\u00e1i sang ph\u1ea3i",
"Emoticons": "Bi\u1ec3u t\u01b0\u1ee3ng c\u1ea3m x\u00fac",
"Robots": "Robots",
"Document properties": "Thu\u1ed9c t\u00ednh t\u00e0i li\u1ec7u",
"Title": "Ti\u00eau \u0111\u1ec1",
"Keywords": "T\u1eeb kho\u00e1",
"Encoding": "M\u00e3 ho\u00e1",
"Description": "Mi\u00eau t\u1ea3",
"Author": "Neo",
"Fullscreen": "\u0110\u1ea7y m\u00e0n h\u00ecnh",
"Horizontal line": "G\u1ea1ch ngang",
"Horizontal space": "Kho\u1ea3ng c\u00e1ch ngang",
"Insert\/edit image": "Th\u00eam \/ s\u1eeda h\u00ecnh \u1ea3nh",
"General": "T\u1ed5ng h\u1ee3p",
"Advanced": "N\u00e2ng cao",
"Source": "Ngu\u1ed3n",
"Border": "\u0110\u01b0\u1eddng vi\u1ec1n",
"Constrain proportions": "H\u1ea1n ch\u1ebf t\u1ef7 l\u1ec7",
"Vertical space": "Kho\u1ea3ng c\u00e1ch d\u1ecdc",
"Image description": "Mi\u00eau t\u1ea3 h\u00ecnh \u1ea3nh",
"Style": "Ki\u1ec3u",
"Dimensions": "K\u00edch th\u01b0\u1edbc",
"Insert image": "Ch\u00e8n \u1ea3nh",
"Zoom in": "Ph\u00f3ng to",
"Contrast": "\u0110\u1ed9 t\u01b0\u01a1ng ph\u1ea3n",
"Back": "Tr\u1edf l\u1ea1i",
"Gamma": "Gamma",
"Flip horizontally": "L\u1eadt ngang",
"Resize": "Thay \u0111\u1ed5i k\u00edch th\u01b0\u1edbc",
"Sharpen": "\u0110\u1ed9 s\u1eafc n\u00e9t",
"Zoom out": "Thu nh\u1ecf",
"Image options": "T\u00f9y ch\u1ecdn h\u00ecnh \u1ea3nh",
"Apply": "\u00c1p d\u1ee5ng",
"Brightness": "\u0110\u1ed9 s\u00e1ng",
"Rotate clockwise": "Xoay theo chi\u1ec1u kim \u0111\u1ed3ng h\u1ed3",
"Rotate counterclockwise": "Xoay ng\u01b0\u1ee3c chi\u1ec1u kim \u0111\u1ed3ng",
"Edit image": "S\u1eeda \u1ea3nh",
"Color levels": "M\u1ee9c \u0111\u1ed9 m\u00e0u s\u1eafc",
"Crop": "X\u00e9n",
"Orientation": "\u0110\u1ecbnh h\u01b0\u1edbng",
"Flip vertically": "L\u1eadt d\u1ecdc",
"Invert": "\u0110\u1ea3o ng\u01b0\u1ee3c",
"Insert date\/time": "Th\u00eam ng\u00e0y \/ gi\u1edd",
"Remove link": "Xo\u00e1 li\u00ean k\u1ebft",
"Url": "Li\u00ean k\u1ebft",
"Text to display": "Ch\u1eef hi\u1ec3n th\u1ecb",
"Anchors": "Ghim",
"Insert link": "Th\u00eam li\u00ean k\u1ebft",
"New window": "C\u1eeda s\u1ed5 m\u1edbi",
"None": "Kh\u00f4ng",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL b\u1ea1n nh\u1eadp v\u00e0o c\u00f3 v\u1ebb l\u00e0 m\u1ed9t li\u00ean k\u1ebft b\u00ean ngo\u00e0i. B\u1ea1n c\u00f3 mu\u1ed1n th\u00eam ti\u1ec1n t\u1ed1 http:\/\/ c\u1ea7n thi\u1ebft?",
"Target": "M\u1ee5c ti\u00eau",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL b\u1ea1n nh\u1eadp v\u00e0o c\u00f3 v\u1ebb l\u00e0 m\u1ed9t \u0111\u1ecba ch\u1ec9 email. B\u1ea1n c\u00f3 mu\u1ed1n th\u00eam c\u00e1c y\u00eau c\u1ea7u mailto: ti\u1ec1n t\u1ed1?",
"Insert\/edit link": "Th\u00eam \/ s\u1eeda li\u00ean k\u1ebft",
"Insert\/edit video": "Th\u00eam \/ s\u1eeda video",
"Poster": "Ng\u01b0\u1eddi \u0111\u0103ng",
"Alternative source": "Ngu\u1ed3n thay th\u1ebf",
"Paste your embed code below:": "D\u00e1n m\u00e3 embed v\u00e0o:",
"Insert video": "Th\u00eam video",
"Embed": "Embed",
"Nonbreaking space": "Kh\u00f4ng ng\u1eaft kho\u1ea3ng",
"Page break": "Ng\u1eaft trang",
"Paste as text": "D\u00e1n nh\u01b0 v\u0103n b\u1ea3n",
"Preview": "Xem tr\u01b0\u1edbc",
"Print": "In",
"Save": "L\u01b0u",
"Could not find the specified string.": "Kh\u00f4ng t\u00ecm th\u1ea5y chu\u1ed7i y\u00eau c\u1ea7u",
"Replace": "Thay th\u1ebf",
"Next": "Sau",
"Whole words": "T\u1ea5t c\u1ea3 \u0111o\u1ea1n",
"Find and replace": "T\u00ecm v\u00e0 thay th\u1ebf",
"Replace with": "Thay th\u1ebf b\u1eb1ng",
"Find": "T\u00ecm",
"Replace all": "Thay th\u1ebf t\u1ea5t c\u1ea3",
"Match case": "Ph\u00e2n bi\u1ec7t hoa th\u01b0\u1eddng",
"Prev": "Tr\u01b0\u1edbc",
"Spellcheck": "Ki\u1ec3m tra ch\u00ednh t\u1ea3",
"Finish": "Ho\u00e0n t\u1ea5t",
"Ignore all": "L\u1edd t\u1ea5t c\u1ea3",
"Ignore": "L\u1edd qua",
"Add to Dictionary": "Th\u00eam v\u00e0o t\u1eeb \u0111i\u1ec3n",
"Insert row before": "Th\u00eam d\u00f2ng ph\u00eda tr\u00ean",
"Rows": "D\u00f2ng",
"Height": "Cao",
"Paste row after": "D\u00e1n v\u00e0o ph\u00eda sau, d\u01b0\u1edbi",
"Alignment": "Canh ch\u1ec9nh",
"Border color": "M\u00e0u vi\u1ec1n",
"Column group": "Nh\u00f3m c\u1ed9t",
"Row": "D\u00f2ng",
"Insert column before": "Th\u00eam c\u1ed9t b\u00ean tr\u00e1i",
"Split cell": "Chia \u00f4",
"Cell padding": "Kho\u1ea3ng c\u00e1ch trong \u00f4",
"Cell spacing": "Kho\u1ea3ng c\u00e1ch \u00f4",
"Row type": "Lo\u1ea1i d\u00f2ng",
"Insert table": "Th\u00eam b\u1ea3ng",
"Body": "N\u1ed9i dung",
"Caption": "Ti\u00eau \u0111\u1ec1",
"Footer": "Ch\u00e2n",
"Delete row": "Xo\u00e1 d\u00f2ng",
"Paste row before": "D\u00e1n v\u00e0o ph\u00eda tr\u01b0\u1edbc, tr\u00ean",
"Scope": "Quy\u1ec1n",
"Delete table": "Xo\u00e1 b\u1ea3ng",
"H Align": "X\u1ebfp ngang",
"Top": "\u0110\u1ec9nh",
"Header cell": "Ti\u00eau \u0111\u1ec1 \u00f4",
"Column": "C\u1ed9t",
"Row group": "Nh\u00f3m d\u00f2ng",
"Cell": "\u00d4",
"Middle": "Gi\u1eefa",
"Cell type": "Lo\u1ea1i \u00f4",
"Copy row": "Ch\u00e9p d\u00f2ng",
"Row properties": "Thu\u1ed9c t\u00ednh d\u00f2ng",
"Table properties": "Thu\u1ed9c t\u00ednh b\u1ea3ng",
"Bottom": "\u0110\u00e1y",
"V Align": "X\u1ebfp d\u1ecdc",
"Header": "Ti\u00eau \u0111\u1ec1",
"Right": "Ph\u1ea3i",
"Insert column after": "Th\u00eam c\u1ed9t b\u00ean ph\u1ea3i",
"Cols": "C\u1ed9t",
"Insert row after": "Th\u00eam d\u00f2ng ph\u00eda d\u01b0\u1edbi",
"Width": "R\u1ed9ng",
"Cell properties": "Thu\u1ed9c t\u00ednh \u00f4",
"Left": "Tr\u00e1i",
"Cut row": "C\u1eaft d\u00f2ng",
"Delete column": "Xo\u00e1 c\u1ed9t",
"Center": "Gi\u1eefa",
"Merge cells": "N\u1ed1i \u00f4",
"Insert template": "Th\u00eam m\u1eabu",
"Templates": "M\u1eabu",
"Background color": "M\u00e0u n\u1ec1n",
"Custom...": "T\u00f9y ch\u1ecdn...",
"Custom color": "M\u00e0u t\u00f9y ch\u1ecdn",
"No color": "Kh\u00f4ng m\u00e1u",
"Text color": "M\u00e0u ch\u1eef",
"Show blocks": "Hi\u1ec3n th\u1ecb kh\u1ed1i",
"Show invisible characters": "Hi\u1ec3n th\u1ecb c\u00e1c k\u00fd t\u1ef1 \u1ea9n",
"Words: {0}": "T\u1eeb: {0}",
"Insert": "Th\u00eam",
"File": "T\u1eadp tin",
"Edit": "S\u1eeda",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Khu v\u1ef1c so\u1ea1n th\u1ea3o. Nh\u1ea5n ALT-F9 \u0111\u1ec3 hi\u1ec7n menu, ALT-F10 \u0111\u1ec3 hi\u1ec7n thanh c\u00f4ng c\u1ee5. C\u1ea7n tr\u1ee3 gi\u00fap nh\u1ea5n ALT-0",
"Tools": "C\u00f4ng c\u1ee5",
"View": "Xem",
"Table": "B\u1ea3ng",
"Format": "\u0110\u1ecbnh d\u1ea1ng"
});