tinymce.addI18n('es_MX',{
"Cut": "Cortar",
"Heading 5": "Encabezados 5",
"Header 2": "Encabezado 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Su navegador no soporta acceso directo al portapapeles. Por favor haga uso de la combinaci\u00f3n de teclas Ctrl+X para cortar, Ctrl+C para copiar y Ctrl+V para pegar con el teclado. ",
"Heading 4": "Encabezados 4",
"Div": "Div",
"Heading 2": "Encabezados 2",
"Paste": "Pegar",
"Close": "Cerrar",
"Font Family": "Tipo de letra",
"Pre": "Pre",
"Align right": "Alinear a la derecha",
"New document": "Nuevo documento",
"Blockquote": "Blockquote",
"Numbered list": "Lista numerada",
"Heading 1": "Encabezados 1",
"Headings": "Encabezados",
"Increase indent": "Incrementar identado",
"Formats": "Formato",
"Headers": "Encabezado",
"Select all": "Seleccionar todo",
"Header 3": "Encabezado 3",
"Blocks": "Bloque",
"Undo": "Rehacer",
"Strikethrough": "Tachado",
"Bullet list": "Lista de vi\u00f1eta",
"Header 1": "Encabezado 1",
"Superscript": "\u00cdndice",
"Clear formatting": "Limpiar formato",
"Font Sizes": "Tama\u00f1o de letra",
"Subscript": "Sub\u00edndice",
"Header 6": "Encabezado 6",
"Redo": "Deshacer",
"Paragraph": "P\u00e1rrafo",
"Ok": "Aceptar",
"Bold": "Negrita",
"Code": "C\u00f3digo",
"Italic": "Cursiva",
"Align center": "Centrar",
"Header 5": "Encabezado 5",
"Heading 6": "Encabezados 6",
"Heading 3": "Encabezados 3",
"Decrease indent": "Decrementar identado",
"Header 4": "Encabezado 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Se pegar\u00e1 en texto plano. El contenido se pegar\u00e1 como texto plano hasta que desactive esta opci\u00f3n.",
"Underline": "Subrayado",
"Cancel": "Cancelar",
"Justify": "Justificar",
"Inline": "En l\u00ednea",
"Copy": "Copiar",
"Align left": "Alinear a la izquierda",
"Visual aids": "Ayuda visual",
"Lower Greek": "Griega min\u00fascula",
"Square": "Cuadro",
"Default": "Por defecto",
"Lower Alpha": "Alfa min\u00fascula",
"Circle": "Circulo",
"Disc": "Disco",
"Upper Alpha": "Alfa may\u00fascula",
"Upper Roman": "May\u00fascula Romana",
"Lower Roman": "Romano min\u00fascula",
"Name": "Nombre",
"Anchor": "Anclar",
"You have unsaved changes are you sure you want to navigate away?": "No se  han guardado los cambios. \u00bfSeguro que desea abandonar la p\u00e1gina?",
"Restore last draft": "Restaurar el \u00faltimo borrador",
"Special character": "Caracter especial",
"Source code": "C\u00f3digo fuente",
"B": "B",
"R": "R",
"G": "G",
"Color": "Color",
"Right to left": "Derecha a Izquierda",
"Left to right": "Izquierda a derecha",
"Emoticons": "Emoticones",
"Robots": "Robots",
"Document properties": "Propiedades del documento",
"Title": "T\u00edtulo",
"Keywords": "Palabras clave",
"Encoding": "Codificaci\u00f3n",
"Description": "Descripci\u00f3n ",
"Author": "Autor",
"Fullscreen": "Pantalla completa",
"Horizontal line": "L\u00ednea Horizontal",
"Horizontal space": "Espacio horizontal",
"Insert\/edit image": "Insertar\/editar imagen",
"General": "General",
"Advanced": "Avanzado",
"Source": "Origen",
"Border": "Borde",
"Constrain proportions": "Restringir proporciones",
"Vertical space": "Espacio vertical",
"Image description": "Descripci\u00f3n de imagen",
"Style": "Estilo",
"Dimensions": "Dimensiones",
"Insert image": "Insertar imagen",
"Zoom in": "Acercar",
"Contrast": "Contraste",
"Back": "Regresar",
"Gamma": "Gamma",
"Flip horizontally": "Volter horizontalmente",
"Resize": "Cambiar tama\u00f1o",
"Sharpen": "Nitidez",
"Zoom out": "Alejar",
"Image options": "Opciones de la imagen",
"Apply": "Aplicar",
"Brightness": "Brillo",
"Rotate clockwise": "Rotar en sentido de las manecillas",
"Rotate counterclockwise": "Rotar en sentido contrario a las manecillas",
"Edit image": "Editar imagen",
"Color levels": "Niveles de Color",
"Crop": "Recortar",
"Orientation": "Orientaci\u00f3n",
"Flip vertically": "Voltear verticalmente",
"Invert": "Invertir",
"Insert date\/time": "Insertar fecha\/hora",
"Remove link": "Eliminar elnace",
"Url": "Url",
"Text to display": "Texto a mostrar",
"Anchors": "Anclas",
"Insert link": "Insertar enlace",
"New window": "Nueva ventana",
"None": "Ninguno",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "El URL que ha ingresado es un enlace externo. \u00bfDesea agregar el prefijo \"http:\/\/\"?",
"Target": "Objetivo",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "El URL que ha insertado tiene formato de correo electr\u00f3nico. \u00bfDesea agregar con prefijo \"mailto:\"?",
"Insert\/edit link": "Inserta\/editar enlace",
"Insert\/edit video": "Insertar\/editar video",
"Poster": "Cartel",
"Alternative source": "Fuente alternativa",
"Paste your embed code below:": "Pegue su c\u00f3digo de inserci\u00f3n abajo:",
"Insert video": "Insertar video",
"Embed": "Incrustar",
"Nonbreaking space": "Espacio de no separaci\u00f3n",
"Page break": "Salto de p\u00e1gina ",
"Paste as text": "Copiar como texto",
"Preview": "Vista previa ",
"Print": "Imprimir",
"Save": "Guardar",
"Could not find the specified string.": "No se ha encontrado la cadena especificada.",
"Replace": "Remplazar",
"Next": "Siguiente",
"Whole words": "Palabras completas",
"Find and replace": "Buscar y reemplazar",
"Replace with": "Remplazar con",
"Find": "Buscar",
"Replace all": "Remplazar todo",
"Match case": "Coincidencia",
"Prev": "Anterior",
"Spellcheck": "Revisi\u00f3n ortogr\u00e1fica",
"Finish": "Terminar",
"Ignore all": "Ignorar todo",
"Ignore": "Ignorar",
"Add to Dictionary": "Agregar al diccionario ",
"Insert row before": "Insertar rengl\u00f3n antes",
"Rows": "Renglones ",
"Height": "Alto",
"Paste row after": "Pegar rengl\u00f3n despu\u00e9s",
"Alignment": "Alineaci\u00f3n ",
"Border color": "Color del borde",
"Column group": "Grupo de columnas",
"Row": "Rengl\u00f3n ",
"Insert column before": "Insertar columna antes",
"Split cell": "Dividir celdas",
"Cell padding": "Relleno de la celda",
"Cell spacing": "Espacio entre celdas",
"Row type": "Tipo de rengl\u00f3n ",
"Insert table": "Insertar tabla",
"Body": "Cuerpo",
"Caption": "Subt\u00edtulo",
"Footer": "Pie",
"Delete row": "Eliminar rengl\u00f3n ",
"Paste row before": "Pegar rengl\u00f3n antes",
"Scope": "Alcance",
"Delete table": "Eliminar tabla",
"H Align": "Alineaci\u00f3n Horizontal",
"Top": "Arriba",
"Header cell": "Celda de encabezado",
"Column": "Columna",
"Row group": "Grupo de renglones",
"Cell": "Celda",
"Middle": "Centrado",
"Cell type": "Tipo de celda",
"Copy row": "Copiar rengl\u00f3n ",
"Row properties": "Propiedades del rengl\u00f3n ",
"Table properties": "Propiedades de tabla",
"Bottom": "Abajo",
"V Align": "Alineaci\u00f3n Vertical",
"Header": "Encabezado",
"Right": "Derecha",
"Insert column after": "Insertar columna despu\u00e9s",
"Cols": "Columnas",
"Insert row after": "Insertar rengl\u00f3n despu\u00e9s",
"Width": "Ancho",
"Cell properties": "Propiedades de celda",
"Left": "Izquierda",
"Cut row": "Cortar renglon",
"Delete column": "Eliminar columna",
"Center": "Centro",
"Merge cells": "Unir celdas",
"Insert template": "Insertar plantilla",
"Templates": "Plantilla",
"Background color": "Color de fondo",
"Custom...": "Personalizar",
"Custom color": "Perzonalizar color",
"No color": "Sin color",
"Text color": "Color de letra",
"Show blocks": "Mostrar bloques",
"Show invisible characters": "Mostrar caracteres invisibles",
"Words: {0}": "Palabras:{0}",
"Insert": "Insertar",
"File": "Archivo",
"Edit": "Editar",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Presione dentro del \u00e1rea de texto ALT-F9 para invocar el men\u00fa, ALT-F10 para la barra de herramientas y ALT-0 para la ayuda.",
"Tools": "Herramientas",
"View": "Vistas",
"Table": "Tabla",
"Format": "Formato"
});